/*----------------------------------------------------------------
 * comix.c - prehravani komixovych animaci
 *----------------------------------------------------------------
 */

#include <stdio.h>
#include <stdarg.h>
#include <allegro.h>
#include "criterr.h"       /* prototype for `critical_error' */
#include "variable.h"
#include "comix.h"
#include "string.h"
#include "sound.h"



BITMAP *c_image[MAX_COMIX_IMAGE];
VIRTUAL_IMAGE_TYPE v_image[MAX_VIRTUAL_IMAGE];
int c_image_count = 0;
int v_image_count = 0;
SAMPLE *c_sound[MAX_COMIX_SOUND];

int scroll_tempo_old, scroll_tempo;
int scroll_x, scroll_y;   // rychlost a posunuti scrollu





void c_cls()
{
#ifdef TO_VIDEO
    acquire_bitmap(game_screen);
#endif
	clear(game_screen);
	//blit(game_screen2, game_screen, 0, 0, 0, 0, SCREEN_W, SCREEN_H);
#ifdef TO_VIDEO
    release_bitmap(game_screen);
#endif
}



void c_blit(int index, int X, int Y)
{
#ifdef TO_VIDEO
    acquire_bitmap(game_screen);
#endif
	blit(c_image[v_image[index].image], game_screen, 0, 0, X, Y, v_image[index].width, v_image[index].height);
#ifdef TO_VIDEO
    release_bitmap(game_screen);
#endif
}


void c_mblit(int index, int X, int Y)
{
#ifdef TO_VIDEO
    acquire_bitmap(game_screen);
#endif
	masked_blit(c_image[v_image[index].image], game_screen, 0, 0, X, Y, v_image[index].width, v_image[index].height);
#ifdef TO_VIDEO
    release_bitmap(game_screen);
#endif
}



void c_refresh()
{
#ifdef TO_VIDEO
    acquire_bitmap(game_screen);
	acquire_screen();
#endif
	blit(game_screen, screen, 0, 0, 0, 0, SCREEN_W, SCREEN_H);
#ifdef TO_VIDEO
	release_screen();
	release_bitmap(game_screen);
#endif
}




void c_fade(int index, int tempo, int X, int Y)
{
    int alpha;

   for (alpha=0; alpha<256; alpha+=16) {
#ifdef TO_VIDEO
    acquire_screen();
	acquire_bitmap(game_screen);
#endif
      set_trans_blender(0, 0, 0, alpha);
      draw_trans_sprite(game_screen, c_image[v_image[index].image], X, Y);
      blit(game_screen, screen, 0, 0, 0, 0, SCREEN_W, SCREEN_H);
#ifdef TO_VIDEO
    release_screen();
	release_bitmap(game_screen);
#endif
      if (key[KEY_SPACE])
      {
        clear_keybuf();
        break;
      }
      if (key[KEY_ESC])
      {
        break;
      }
   }
   c_blit(index, X, Y);
   c_refresh();
}


void c_scroll(int count, int mx, int my)
{
    int i;

    for (i=0; i<count; i++)
    {
#ifdef TO_VIDEO
	acquire_bitmap(game_screen);
#endif

        if ((my>=0) && (mx>=0))
            blit(game_screen, game_screen, 0, 0, mx, my, SCREEN_W-mx, SCREEN_H-my);
        if ((my>0) && (mx<=0))
            blit(game_screen, game_screen, -mx, 0, 0, my, SCREEN_W+mx, SCREEN_H-my);
        if ((my<=0) && (mx>=0))
            blit(game_screen, game_screen, 0, -my, mx, 0, SCREEN_W-mx, SCREEN_H+my);
        if ((my<0) && (mx<=0))
            blit(game_screen, game_screen, -mx, -my, 0, 0, SCREEN_W+mx, SCREEN_H+my);
#ifdef TO_VIDEO
    release_bitmap(game_screen);
#endif
      if (key[KEY_SPACE])
      {
          clear_keybuf();
          break;
      }
      if (key[KEY_ESC])
      {
        break;
      }


    }
    //FIXME: mozna to tu blbne, chce to vycistit frontu misto readkey()
}

void c_ride(int index, int count, int X, int Y, int mx, int my)
{
    int i;
    int x1, x2, y1, y2;

    if (mx>=0)
    {
        x1 = X;
        x2 = SCREEN_W;
    } else {
        x1 = 0;
        x2 = X;
    }
    if (my>=0)
    {
        y1 = Y;
        y2 = SCREEN_H;
    } else {
        y1 = 0;
        y2 = Y;
    }
    if (x1<0)
        x1 = 0;
    if (y1<0)
        y1 = 0;
    if (x2>SCREEN_W)
        x2=SCREEN_W;
    if (y2>SCREEN_H)
        y2=SCREEN_H;
#ifdef TO_VIDEO
    acquire_screen();
#endif
    set_clip(game_screen, x1, y1, x2, y2);
#ifdef TO_VIDEO
    release_screen();
#endif
    for (i=0; i<count; i++)
    {
#ifdef TO_VIDEO
	acquire_bitmap(game_screen);
#endif
    masked_blit(c_image[v_image[index].image], game_screen, 0, 0, X, Y, v_image[index].width, v_image[index].height);
#ifdef TO_VIDEO
	release_bitmap(game_screen);
#endif
    X+=mx;
    Y+=my;
      if (key[KEY_SPACE])
      {
          clear_keybuf();
          break;
      }
      if (key[KEY_ESC])
      {
        break;
      }
    }
#ifdef TO_VIDEO
    acquire_screen();
#endif
    set_clip(game_screen, 0, 0, SCREEN_W, SCREEN_H);
#ifdef TO_VIDEO
    release_screen();
#endif

}







//***************************************************
//     show_all
//***************************************************


void show_all()
{
    int i;
	int px, py;

    c_cls();

    for (i=0; i<MAX_VIRTUAL_IMAGE; i++)
        if ((v_image[i].visible) && (c_image[v_image[i].image] != NULL))
        {
#ifdef TO_VIDEO
	acquire_bitmap(game_screen);
	//	acquire_bitmap(c_image[v_image[i].image]);
#endif
	if (v_image[i].fade)
	{
		set_trans_blender(0, 0, 0, v_image[i].fade);
		draw_trans_sprite(game_screen, c_image[v_image[i].image], v_image[i].X, v_image[i].Y);
	}
	else
		if ((v_image[i].re_width) || (v_image[i].re_height))
		{
			px = (int)v_image[i].width*(v_image[i].re_width/10000.0);
			py = v_image[i].height*(v_image[i].re_height/10000.0);
			/*
			masked_stretch_blit(c_image[v_image[i].image], game_screen,
				v_image[i].anim_x, v_image[i].anim_y,
				v_image[i].width, v_image[i].height,
				v_image[i].X, v_image[i].Y,
				v_image[i].width*(v_image[i].re_width/10000.0),
				v_image[i].height*(v_image[i].re_height/10000.0));
				*/
			masked_stretch_blit(c_image[v_image[i].image], game_screen,
				v_image[i].anim_x, v_image[i].anim_y,
				v_image[i].width, v_image[i].height,
				v_image[i].X + (v_image[i].width-px)/2,
				v_image[i].Y + (v_image[i].height-py)/2,
				px,
				py);
		}
		else
			masked_blit(c_image[v_image[i].image], game_screen, v_image[i].anim_x, v_image[i].anim_y, v_image[i].X, v_image[i].Y, v_image[i].width, v_image[i].height);
#ifdef TO_VIDEO
    release_bitmap(game_screen);
	//release_bitmap(c_image[v_image[i].image]);
#endif
        }
    c_refresh();

}










//***************************************************
//     move_one
//***************************************************



void move_one(int index)
{
    int mx, my;

    //if (v_image[index].effect == 1)
	if ((v_image[index].X != v_image[index].new_X) ||
		(v_image[index].Y != v_image[index].new_Y))
    {
        mx = v_image[index].new_X - v_image[index].X;
        my = v_image[index].new_Y - v_image[index].Y;


        if (mx>0)
        {
            if (mx>v_image[index].param1)
                mx = v_image[index].param1;
        } else {
            if ((mx<v_image[index].param1) && (mx != 0))
                mx = v_image[index].param1;
		}
        if (my>0)
        {
            if (my>v_image[index].param2)
                my = v_image[index].param2;
        } else {
            if ((my<v_image[index].param2) && (my != 0))
                my = v_image[index].param2;
		}
        v_image[index].X += mx;
        v_image[index].Y += my;
    }
}







//***************************************************
//     move_all
//***************************************************



void move_all()
{
    int i;
    for (i=0; i<MAX_VIRTUAL_IMAGE; i++)
	{
		//if (v_image[i].old < cas - 1000)
		//	v_image[i].old = cas;
        if (v_image[i].visible)
        {
#ifdef DEBUG_VERSION
            fprintf(debugfile,"! OLD: %d  CAS:%d\n", v_image[i].old, cas);
#endif

            while ((v_image[i].old+v_image[i].tempo)<cas)
            {
                v_image[i].old += v_image[i].tempo;
				//v_image[i].old += v_image[i].tempo + 1;
                //if (v_image[i].effect != 0)
                //{
                move_one(i);
                //v_image[i].old = cas;
               // }
               //else
               //v_image[i].old = cas;
            }
        }
		//fade
		if ((v_image[i].fade) || (v_image[i].fade_value))
		{
			v_image[i].fade += v_image[i].fade_value;
			if (v_image[i].fade<0)
			{
				v_image[i].fade = 0;
				v_image[i].fade_value = 0;
				v_image[i].visible = 0;
			}
			if (v_image[i].fade>255)
			{
				v_image[i].fade = 0;
				v_image[i].fade_value = 0;
				v_image[i].visible = 1;
			}
		}

		//resize
		if ((v_image[i].re_width) || (v_image[i].re_height))
		{
			v_image[i].re_width += v_image[i].r_w;
			v_image[i].re_height += v_image[i].r_h;
			if (v_image[i].re_width<0)
			{
				v_image[i].re_width = 0;
				v_image[i].r_w = 0;
			}
			if (v_image[i].re_height<0)
			{
				v_image[i].re_height = 0;
				v_image[i].r_h = 0;
			}
			if ((v_image[i].re_width == 0) &&
				(v_image[i].re_height == 0))
				v_image[i].visible = 0;
		}
	}

    if (scroll_tempo>0)
        while (scroll_tempo_old<cas)
        {
            scroll_tempo_old += scroll_tempo;
            for (i=0; i<MAX_VIRTUAL_IMAGE; i++)
                if (v_image[i].visible != 0)
                {
                    v_image[i].X += scroll_x;
                    v_image[i].Y += scroll_y;
                    v_image[i].new_X += scroll_x;
                    v_image[i].new_Y += scroll_y;
                }
        }

    //ANIME
/*
    type:
        0 .. z leva do prava
        1 .. z prava do leva
        2 .. pingpong
        3 .. random
*/
        //FIXME: random!
    for (i=0; i<MAX_VIRTUAL_IMAGE; i++)
    {
        if (v_image[i].anim_count != 0)
        {

            while (v_image[i].anim_tempo_old<cas)
            {
                switch (v_image[i].anim_type)
                {

                case 1:
                    v_image[i].anim_tempo_old += v_image[i].anim_tempo;
                    if (v_image[i].anim_actual > 0)
                        v_image[i].anim_actual--;
                    else
                        v_image[i].anim_actual = v_image[i].anim_count - 1;
                    break;

                case 2:
                    v_image[i].anim_tempo_old += v_image[i].anim_tempo;
                    v_image[i].anim_actual += v_image[i].anim_pingpong;
                    if (v_image[i].anim_actual == 0)
                        v_image[i].anim_pingpong = 1;
                    if (v_image[i].anim_actual == (v_image[i].anim_count - 1))
                        v_image[i].anim_pingpong = -1;
                    break;


                default:
                    v_image[i].anim_tempo_old += v_image[i].anim_tempo;
                    v_image[i].anim_actual++;
                    if (v_image[i].anim_actual == v_image[i].anim_count)
                        v_image[i].anim_actual = 0;
                    break;
                }
                v_image[i].anim_x = v_image[i].anim_actual * v_image[i].width;
            }
        }
    }
}












void c_delay(int count)
{
    long old_cas;
    long old;
	tovy_timer();
    old_cas = cas;
    old = cas;
	//old_one = cas;
    c_refresh();
    while ((old_cas + count>cas) && (!(key[KEY_SPACE])) && (!key[KEY_ESC]) && !(mouse_b & 1))
    {
        show_all();
		if (key[KEY_B])
			save_screen();

        tovy_timer();
//        if (cas>old)
//        {
            while (cas>old) // je to tu kdyby krok byl vetsi nez 1
            {
                old++;
                move_all();
            }
//        }


    }
    show_all();

    //FIXME: mozna to tu blbne, chce to vycistit frontu misto readkey()
    if (key[KEY_SPACE])
        clear_keybuf();
}















//***************************************************
//     comix_play
//***************************************************



int comix_play(char *name)
{

    FILE *file;
    char filename[40];
    char command[40];
    char iname[40];
    char fname[40];
    int index;
    int i;
    int quit = 0;
	int pan, vel;
	int X, Y;
	//int repeat;


    scroll_tempo = 0;
    scroll_x = 0;
    scroll_y = 0;

    for (i=0; i<MAX_VIRTUAL_IMAGE; i++)
        v_image[i].visible = 0;
    for (i=0; i<MAX_COMIX_IMAGE; i++)
        c_image[i] = NULL;
    for (i=0; i<MAX_COMIX_SOUND; i++)
        c_sound[i] = NULL;


#ifdef TO_VIDEO
    acquire_bitmap(game_screen);
#endif
set_clip(game_screen, 0, 0, 639, 479);
#ifdef TO_VIDEO
    release_bitmap(game_screen);
#endif

    tovy_timer();

    //c_cls();
    //c_refresh();

    strcpy(filename, COMIX_DIR);
    strcat(filename, name);
#ifdef DEBUG_VERSION
    fprintf(debugfile, "-----\nNacitam comix %s\n", filename);
#endif
    file = fopen( filename, "r");
    if( !file ) {
    critical_error ("Unable to open file %s", filename);
    }



    while ((fscanf(file, "%s", command)!=EOF) || (quit))
    {
#ifdef DEBUG_VERSION
        fprintf(debugfile, "NACTENO: %s\n", command);
#endif

        // image
        if (strcmp(command,"image")==0)
        {
            fscanf(file, " %d %s\n", &index, iname);
            strcpy(fname, COMIX_DIR);
            strcat(fname, iname);
            c_image[index] = load_bitmap(fname, pal);
			//c_image[index] = load_bmp(fname, pal);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "NEW IMAGE no. %d: %s\n", index, fname);
#endif
        }
        // destroy
        if (strcmp(command,"destroy")==0)
        {
            fscanf(file, " %d\n", &index);
            destroy_bitmap(c_image[index]);
			c_image[index] = NULL;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "DESTROY IMAGE no. %d!\n", index);
#endif
        }
        // delay
        if (strcmp(command,"delay")==0)
        {
            fscanf(file, " %d\n", &index);
            c_delay(index);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "DELAY no. %d!\n", index);
#endif
        }
        // cls
        if (strcmp(command,"cls")==0)
        {
            for (i=0; i<MAX_VIRTUAL_IMAGE; i++)
                v_image[i].visible = 0;
            fscanf(file, "\n");
            c_cls();
#ifdef DEBUG_VERSION
            fprintf(debugfile, "CLS\n");
#endif
        }
        // virtual
        if (strcmp(command,"virtual")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, " %d %d %d", &v_image[index].image, &v_image[index].pos_X, &v_image[index].pos_Y);
            fscanf(file, " %d %d\n", &v_image[index].width, &v_image[index].height);
            v_image[index].X = 0;
            v_image[index].Y = 0;
			v_image[index].fade = 0;
			v_image[index].fade_value = 0;
            v_image[index].effect = 0;
            v_image[index].tempo = 1;
            v_image[index].type = 0;
            v_image[index].new_X = 0;
            v_image[index].new_Y = 0;
            v_image[index].X = 0;
            v_image[index].Y = 0;
            v_image[index].visible = 0;
            v_image[index].param1 = 0;
            v_image[index].param2 = 0;
            v_image[index].anim_count = 0;
            v_image[index].anim_x = v_image[index].pos_X;
            v_image[index].anim_y = v_image[index].pos_Y;
            v_image[index].anim_tempo = 0;
            v_image[index].anim_pingpong = 1;
			v_image[index].re_height = 0;
			v_image[index].re_width = 0;
			v_image[index].r_h = 0;
			v_image[index].r_w = 0;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "VIRTUAL %d !\n", index);
#endif
        }
        // visible on
        if (strcmp(command,"vis_on")==0)
        {
            fscanf(file, " %d\n", &index);
            v_image[index].visible = 1;
            v_image[index].old = cas;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "VISIBLE ON!\n");
#endif
        }
		// visible off
        if (strcmp(command,"vis_off")==0)
        {
            fscanf(file, " %d\n", &index);
            v_image[index].visible = 0;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "VISIBLE OFF!\n");
#endif
        }
		// move XY
        if (strcmp(command,"move")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d %d %d %d\n", &v_image[index].new_X, &v_image[index].new_Y, &v_image[index].param1, &v_image[index].param2, &v_image[index].tempo);
			if (v_image[index].tempo < 1)
				v_image[index].tempo = 1;
            //v_image[index].effect = 1;
            tovy_timer();
            v_image[index].old = cas;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "MOVE!\n");
#endif
        }
		// set XY
        if (strcmp(command,"setxy")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d\n", &v_image[index].X, &v_image[index].Y);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "SET!\n");
#endif
        }
		// fade index poc_hodnota rychlost(0-255)
        if (strcmp(command,"fade")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d\n", &v_image[index].fade, &v_image[index].fade_value);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "FADE!\n");
#endif
        }
		// setrel index MX MY (relativni souradnice = prirustky)
        if (strcmp(command,"setreal")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d\n", &X, &Y);
			v_image[index].X += X;
			v_image[index].Y += Y;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "SETREAL!\n");
#endif
        }
		// movereal index MX MY (relativni souradnice = prirustky)
        if (strcmp(command,"movereal")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d\n", &X, &Y);
			//v_image[index].effect = 1;
			v_image[index].new_X += X;
			v_image[index].new_Y += Y;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "MOVEREAL!\n");
#endif
        }
		// getXY index index_odkud
        if (strcmp(command,"getXY")==0)
        {
            fscanf(file, " %d %d\n", &index, &X);
			v_image[index].X = v_image[X].X;
			v_image[index].X = v_image[X].X;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "GETXY!\n");
#endif
        }
		// resize index width height r_w r_h
        if (strcmp(command,"resize")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d ", &v_image[index].re_width, &v_image[index].re_height);
			fscanf(file, "%d %d\n", &v_image[index].r_w, &v_image[index].r_h);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "RESIZE!\n");
#endif
        }
		// resize_rel index width height r_w r_h
        if (strcmp(command,"resize_rel")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d ", &X, &Y);
			v_image[index].re_width = v_image[index].width * (X/10);
			v_image[index].re_height = v_image[index].height * (Y/10);
			fscanf(file, "%d %d ", &X, &Y);
			v_image[index].r_w = v_image[index].width * (X/10);
			v_image[index].r_h = v_image[index].height * (Y/10);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "RESIZE_REL!\n");
#endif
        }
		// resize_stop
        if (strcmp(command,"resize_stop")==0)
        {
            fscanf(file, " %d", &index);
			v_image[index].re_width = 0;
			v_image[index].re_height = 0;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "RESIZE_STOP!\n");
#endif
        }

        // quit
        if (strcmp(command,"quit")==0)
        {
            c_cls();
#ifdef DEBUG_VERSION
            fprintf(debugfile, "QUIT!\n");
#endif
        }

		// scroll
        if (strcmp(command,"scroll")==0)
        {
            fscanf(file, " %d %d %d\n", &scroll_tempo, &scroll_x, &scroll_y);
            scroll_tempo_old = cas;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "SCROLL!\n");
#endif
        }
		// scroll OFF
        if (strcmp(command,"scroll_off")==0)
        {
            fscanf(file, "\n");
            scroll_tempo = 0;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "SCROLL OFF!\n");
#endif
        }
		// anime
        if (strcmp(command,"anime")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d\n", &v_image[index].anim_count, &v_image[index].anim_tempo);
            v_image[index].anim_actual = 0;
            v_image[index].anim_tempo_old = cas;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "ANIME!\n");
#endif
        }
		// anim_type
        if (strcmp(command,"anime_type")==0)
		{
            fscanf(file, " %d", &index);
            fscanf(file, "%d\n", &v_image[index].anim_type);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "ANIME_TYPE!\n");
#endif
        }
		// sound
        if (strcmp(command,"sound")==0)
        {
            fscanf(file, " %d %s\n", &index, iname);
            strcpy(fname, COMIX_DIR);
            strcat(fname, iname);
            c_sound[index] = load_sample(fname);
        }
		// destroy sound
        if (strcmp(command,"destroy_sound")==0)
        {
            fscanf(file, " %d", &index);
			destroy_sample(c_sound[index]);
			c_sound[index] = NULL;
        }
		// play sound cislo hlasitost panning
        if (strcmp(command,"play_sound")==0)
        {
            fscanf(file, " %d %d %d", &index, &vel, &pan);
			if (sound_volume)
			{
				play_sample(c_sound[index], (int)(vel*(sound_volume/100.0)), pan, 1000, 0);
			}

        }
		// repeat sound cislo hlasitost panning
        if (strcmp(command,"repeat_sound")==0)
        {
            fscanf(file, " %d %d %d", &index, &vel, &pan);
			if (sound_volume)
				play_sample(c_sound[index], (int)(vel*(sound_volume/100.0)), pan, 1000, 1);
        }
		// stop sample
		if (strcmp(command,"stop_sound")==0)
		{
            fscanf(file, " %d", &index);
			if (sound_volume)
				stop_sample(c_sound[index]);
        }
		// pause
        if (strcmp(command,"pause")==0)
        {
			show_all();
            fscanf(file, "\n");
            clear_keybuf();
            while (!(keypressed()) && !(mouse_b & 1))
				show_all();
            //{
            //}
			while (mouse_b && 1);
            clear_keybuf();
#ifdef DEBUG_VERSION
            fprintf(debugfile, "RIDE!\n");
#endif
        }
		// include
        if (strcmp(command,"include")==0)
        {
            fscanf(file, " %s\n", iname);
			comix_play_file(iname);
        }





    if ((key[KEY_ESC]) || (mouse_b & 1))
        break;
    }

    fclose(file);

   for (i=0; i<MAX_VIRTUAL_IMAGE; i++)
        v_image[i].visible = 0;


    //c_cls();
    //c_refresh();

#ifdef TO_VIDEO
    acquire_bitmap(game_screen);
#endif
set_clip(game_screen, 0, 0, 0, 0);
#ifdef TO_VIDEO
    release_bitmap(game_screen);
#endif


    for (i=0; i<MAX_COMIX_IMAGE; i++)
	{
		if (c_image[i] != NULL)
		{
			destroy_bitmap(c_image[i]);
			c_image[i] = NULL;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "COMIX: nebyl smazan obrazek %d\n", i);
#endif
		}
	}
    for (i=0; i<MAX_COMIX_SOUND; i++)
	{
		if (c_sound[i] != NULL)
		{
			destroy_sample(c_sound[i]);
			c_sound[i] = NULL;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "COMIX: nebyl smazan sampl %d\n", i);
#endif
		}
	}

	// cekani na pusteni tlacitka
	while (mouse_b & 1);

    return 0;
}
















int comix_play_file(char *name)
{

    FILE *file;
    char filename[40];
    char command[40];
    char iname[40];
    char fname[40];
    int index;
    int i;
    int quit = 0;
	int pan, vel;
	int X, Y;
	//int repeat;


    strcpy(filename, COMIX_DIR);
    strcat(filename, name);
#ifdef DEBUG_VERSION
    fprintf(debugfile, "-----\nNacitam comix %s\n", filename);
#endif
    file = fopen( filename, "r");
    if( !file ) {
    critical_error ("Unable to open file %s", filename);
    }



    while ((fscanf(file, "%s", command)!=EOF) || (quit))
    {
#ifdef DEBUG_VERSION
        fprintf(debugfile, "NACTENO: %s\n", command);
#endif

        // image
        if (strcmp(command,"image")==0)
        {
            fscanf(file, " %d %s\n", &index, iname);
            strcpy(fname, COMIX_DIR);
            strcat(fname, iname);
            c_image[index] = load_bitmap(fname, pal);
			//c_image[index] = load_bmp(fname, pal);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "NEW IMAGE no. %d: %s\n", index, fname);
#endif
        }
        // destroy
        if (strcmp(command,"destroy")==0)
        {
            fscanf(file, " %d\n", &index);
            destroy_bitmap(c_image[index]);
			c_image[index] = NULL;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "DESTROY IMAGE no. %d!\n", index);
#endif
        }
        // delay
        if (strcmp(command,"delay")==0)
        {
            fscanf(file, " %d\n", &index);
            c_delay(index);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "DELAY no. %d!\n", index);
#endif
        }
        // cls
        if (strcmp(command,"cls")==0)
        {
            for (i=0; i<MAX_VIRTUAL_IMAGE; i++)
                v_image[i].visible = 0;
            fscanf(file, "\n");
            c_cls();
#ifdef DEBUG_VERSION
            fprintf(debugfile, "CLS\n");
#endif
        }
        // virtual
        if (strcmp(command,"virtual")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, " %d %d %d", &v_image[index].image, &v_image[index].pos_X, &v_image[index].pos_Y);
            fscanf(file, " %d %d\n", &v_image[index].width, &v_image[index].height);
            v_image[index].X = 0;
            v_image[index].Y = 0;
			v_image[index].fade = 0;
			v_image[index].fade_value = 0;
            v_image[index].effect = 0;
            v_image[index].tempo = 1;
            v_image[index].type = 0;
            v_image[index].new_X = 0;
            v_image[index].new_Y = 0;
            v_image[index].X = 0;
            v_image[index].Y = 0;
            v_image[index].visible = 0;
            v_image[index].param1 = 0;
            v_image[index].param2 = 0;
            v_image[index].anim_count = 0;
            v_image[index].anim_x = v_image[index].pos_X;
            v_image[index].anim_y = v_image[index].pos_Y;
            v_image[index].anim_tempo = 0;
            v_image[index].anim_pingpong = 1;
			v_image[index].re_height = 0;
			v_image[index].re_width = 0;
			v_image[index].r_h = 0;
			v_image[index].r_w = 0;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "VIRTUAL %d !\n", index);
#endif
        }
        // visible on
        if (strcmp(command,"vis_on")==0)
        {
            fscanf(file, " %d\n", &index);
            v_image[index].visible = 1;
            v_image[index].old = cas;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "VISIBLE ON!\n");
#endif
        }
		// visible off
        if (strcmp(command,"vis_off")==0)
        {
            fscanf(file, " %d\n", &index);
            v_image[index].visible = 0;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "VISIBLE OFF!\n");
#endif
        }
		// move XY
        if (strcmp(command,"move")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d %d %d %d\n", &v_image[index].new_X, &v_image[index].new_Y, &v_image[index].param1, &v_image[index].param2, &v_image[index].tempo);
			if (v_image[index].tempo < 1)
				v_image[index].tempo = 1;
            //v_image[index].effect = 1;
            tovy_timer();
            v_image[index].old = cas;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "MOVE!\n");
#endif
        }
		// set XY
        if (strcmp(command,"setxy")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d\n", &v_image[index].X, &v_image[index].Y);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "SET!\n");
#endif
        }
		// fade index poc_hodnota rychlost(0-255)
        if (strcmp(command,"fade")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d\n", &v_image[index].fade, &v_image[index].fade_value);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "FADE!\n");
#endif
        }
		// setrel index MX MY (relativni souradnice = prirustky)
        if (strcmp(command,"setreal")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d\n", &X, &Y);
			v_image[index].X += X;
			v_image[index].Y += Y;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "SETREAL!\n");
#endif
        }
		// movereal index MX MY (relativni souradnice = prirustky)
        if (strcmp(command,"movereal")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d\n", &X, &Y);
			//v_image[index].effect = 1;
			v_image[index].new_X += X;
			v_image[index].new_Y += Y;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "MOVEREAL!\n");
#endif
        }
		// getXY index index_odkud
        if (strcmp(command,"getXY")==0)
        {
            fscanf(file, " %d %d\n", &index, &X);
			v_image[index].X = v_image[X].X;
			v_image[index].X = v_image[X].X;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "GETXY!\n");
#endif
        }
		// resize index width height r_w r_h
        if (strcmp(command,"resize")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d ", &v_image[index].re_width, &v_image[index].re_height);
			fscanf(file, "%d %d\n", &v_image[index].r_w, &v_image[index].r_h);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "RESIZE!\n");
#endif
        }
		// resize_rel index width height r_w r_h
        if (strcmp(command,"resize_rel")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d ", &X, &Y);
			v_image[index].re_width = v_image[index].width * (X/10);
			v_image[index].re_height = v_image[index].height * (Y/10);
			fscanf(file, "%d %d ", &X, &Y);
			v_image[index].r_w = v_image[index].width * (X/10);
			v_image[index].r_h = v_image[index].height * (Y/10);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "RESIZE_REL!\n");
#endif
        }
		// resize_stop
        if (strcmp(command,"resize_stop")==0)
        {
            fscanf(file, " %d", &index);
			v_image[index].re_width = 0;
			v_image[index].re_height = 0;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "RESIZE_STOP!\n");
#endif
        }

        // quit
        if (strcmp(command,"quit")==0)
        {
            c_cls();
#ifdef DEBUG_VERSION
            fprintf(debugfile, "QUIT!\n");
#endif
        }

		// scroll
        if (strcmp(command,"scroll")==0)
        {
            fscanf(file, " %d %d %d\n", &scroll_tempo, &scroll_x, &scroll_y);
            scroll_tempo_old = cas;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "SCROLL!\n");
#endif
        }
		// scroll OFF
        if (strcmp(command,"scroll_off")==0)
        {
            fscanf(file, "\n");
            scroll_tempo = 0;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "SCROLL OFF!\n");
#endif
        }
		// anime
        if (strcmp(command,"anime")==0)
        {
            fscanf(file, " %d", &index);
            fscanf(file, "%d %d\n", &v_image[index].anim_count, &v_image[index].anim_tempo);
            v_image[index].anim_actual = 0;
            v_image[index].anim_tempo_old = cas;
#ifdef DEBUG_VERSION
            fprintf(debugfile, "ANIME!\n");
#endif
        }
		// anim_type
        if (strcmp(command,"anime_type")==0)
		{
            fscanf(file, " %d", &index);
            fscanf(file, "%d\n", &v_image[index].anim_type);
#ifdef DEBUG_VERSION
            fprintf(debugfile, "ANIME_TYPE!\n");
#endif
        }
		// sound
        if (strcmp(command,"sound")==0)
        {
            fscanf(file, " %d %s\n", &index, iname);
            strcpy(fname, COMIX_DIR);
            strcat(fname, iname);
            c_sound[index] = load_sample(fname);
        }
		// destroy sound
        if (strcmp(command,"destroy_sound")==0)
        {
            fscanf(file, " %d", &index);
			destroy_sample(c_sound[index]);
			c_sound[index] = NULL;
        }
		// play sound cislo hlasitost panning
        if (strcmp(command,"play_sound")==0)
        {
            fscanf(file, " %d %d %d", &index, &vel, &pan);
			play_sample(c_sound[index], vel, pan, 1000, 0);
        }
		// repeat sound cislo hlasitost panning
        if (strcmp(command,"repeat_sound")==0)
        {
            fscanf(file, " %d %d %d", &index, &vel, &pan);
			if (sound_volume)
				play_sample(c_sound[index], (int)(vel*(sound_volume/100.0)), pan, 1000, 1);
        }
		// stop sample
		if (strcmp(command,"stop_sound")==0)
		{
            fscanf(file, " %d", &index);
			if (sound_volume)
				stop_sample(c_sound[index]);
        }

		// pause
        if (strcmp(command,"pause")==0)
        {
			show_all();
            fscanf(file, "\n");
            clear_keybuf();
            while (!(keypressed()) && !(mouse_b & 1))
            {
				show_all();
            }
            clear_keybuf();
#ifdef DEBUG_VERSION
            fprintf(debugfile, "RIDE!\n");
#endif
        }

    if ((key[KEY_ESC]) || (mouse_b & 1))
        break;
    }

    fclose(file);

    return 0;
}
